#!/usr/bin/env perl
#
# Swap journal abbreviations (column 2 and 3) in three-column abbreviation database
# Abbreviation database is file of multiple rows, one row per journal.
# Each row is of the format 
#	<Full name> = <Abbrev 1> = <Abbrev 2>
# Excess white spaces, as well as leading and trailing white space is ignored.
# Empty lines in journal list are ignored
# Comment lines start with route '#'
# Appart from that, this is a simple find and replace script, no formating done.
#
# The script takes one argument: The journal abbreviation list to transform
# This script might be useful if you download a Journal abbreviation list online 
#	and find out that the order of the two abbreviation styles (with and without dots) 
#	is not as you want them.
#	
# Written by Stilianos Louca, May 09, 2013.
# This script comes with no warranty. Use at your own risk.
#
#------------------------------------------------------------

if($#ARGV < 0){
	die "Missing input file\n";
}

# Get the list of journal names in a variable
open(JOURNALS,  $ARGV[0]) or die "Can't open ".$ARGV[0].": $!";
@journalnames = <JOURNALS>;
close(JOURNALS);

# For each element of the list of journal names we extract the full name of the journal and the abbreviated name
foreach $journame (@journalnames) {
	#remove white space at beginning and end
    $journame_new = $journame;
    $journame_new =~ s/^\h+|\h+$//g;
    
    if(($journame_new eq "") || ($journame_new =~ /^#/)){
    	# is just a comment line or empty line
    	next;
    }
    
	# remove white space around '=' signs
	$journame_new =~ s/\h*=\h*/=/g;
	
	# split based on "="
	if($journame_new =~ /^(.*)=(.*)=(.*)$/){ # has three journal versions
		$full = $1;
		$abbrv1 = $2;
		$abbrv2 = $3;
		$journame = $full." = ".$abbrv2." = ".$abbrv1."\n";
	}else{
		#nothing to swap on this line
		next;
	}
}

# Print to stdout, can be redirected to a file with " > somefile"
$outFile = $ARGV[0].' swapped';
open (OUTFILE, '> '.$outFile) or die "Can't open $outFile: $!";
print OUTFILE @journalnames;
close (OUTFILE);
